# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterSerialNumberHistoryChild(Model):
    """MeterSerialNumberHistoryChild.

    :param previous_serial_number: Previous serial number of the meter
    :type previous_serial_number: str
    :param serial_number_change_date: Date that serial number changed
    :type serial_number_change_date: datetime
    """

    _attribute_map = {
        'previous_serial_number': {'key': 'previousSerialNumber', 'type': 'str'},
        'serial_number_change_date': {'key': 'serialNumberChangeDate', 'type': 'iso-8601'},
    }

    def __init__(self, previous_serial_number=None, serial_number_change_date=None):
        super(MeterSerialNumberHistoryChild, self).__init__()
        self.previous_serial_number = previous_serial_number
        self.serial_number_change_date = serial_number_change_date
