# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListActionApprove(Model):
    """ListActionApprove.

    :param approve:  <span class='property-internal'>Required (defined)</span>
    :type approve: bool
    """

    _attribute_map = {
        'approve': {'key': 'approve', 'type': 'bool'},
    }

    def __init__(self, approve=None):
        super(ListActionApprove, self).__init__()
        self.approve = approve
