# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderUpdateEndDateChild(Model):
    """End Date.

    :param end_date:  <span class='property-internal'>Required when Update is
     set to True</span> <span class='property-internal'>Must be between
     12/31/1899 and 1/1/3000</span>
    :type end_date: datetime
    :param update: Indicates whether or not the header value is being updated
     <span class='property-internal'>Required</span>
    :type update: bool
    """

    _validation = {
        'update': {'required': True},
    }

    _attribute_map = {
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'update': {'key': 'update', 'type': 'bool'},
    }

    def __init__(self, update, end_date=None):
        super(BillHeaderUpdateEndDateChild, self).__init__()
        self.end_date = end_date
        self.update = update
