# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Country(Model):
    """Country.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar country_id:
    :vartype country_id: int
    :ivar name:
    :vartype name: str
    :ivar alpha2_code:
    :vartype alpha2_code: str
    :ivar possible_spellings:
    :vartype possible_spellings: list[str]
    """

    _validation = {
        'country_id': {'readonly': True},
        'name': {'readonly': True},
        'alpha2_code': {'readonly': True},
        'possible_spellings': {'readonly': True},
    }

    _attribute_map = {
        'country_id': {'key': 'countryId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'alpha2_code': {'key': 'alpha2Code', 'type': 'str'},
        'possible_spellings': {'key': 'possibleSpellings', 'type': '[str]'},
    }

    def __init__(self):
        super(Country, self).__init__()
        self.country_id = None
        self.name = None
        self.alpha2_code = None
        self.possible_spellings = None
