# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CreateTemplateFromBill(Model):
    """CreateTemplateFromBill.

    :param template_code: The template code
     Always converted to uppercase <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type template_code: str
    :param note: The template note <span class='property-internal'>Must be
     between 0 and 255 characters</span>
    :type note: str
    """

    _validation = {
        'template_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'template_code': {'key': 'templateCode', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, template_code, note=None):
        super(CreateTemplateFromBill, self).__init__()
        self.template_code = template_code
        self.note = note
