# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterCategoryRequest(Model):
    """MeterCategoryRequest.

    :param meter_group_category_code: The meter category code <span
     class='property-internal'>Must be between 0 and 32 characters</span> <span
     class='property-internal'>Required</span>
    :type meter_group_category_code: str
    :param meter_group_category_info: The meter category info <span
     class='property-internal'>Must be between 0 and 32 characters</span> <span
     class='property-internal'>Required</span>
    :type meter_group_category_info: str
    """

    _validation = {
        'meter_group_category_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'meter_group_category_info': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'meter_group_category_code': {'key': 'meterGroupCategoryCode', 'type': 'str'},
        'meter_group_category_info': {'key': 'meterGroupCategoryInfo', 'type': 'str'},
    }

    def __init__(self, meter_group_category_code, meter_group_category_info):
        super(MeterCategoryRequest, self).__init__()
        self.meter_group_category_code = meter_group_category_code
        self.meter_group_category_info = meter_group_category_info
