# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportBatchChild(Model):
    """ReportBatchChild.

    :param report_batch_id: The report batch ID
    :type report_batch_id: int
    :param report_batch_code: The report batch code
    :type report_batch_code: str
    :param report_batch_name: The report batch name
    :type report_batch_name: str
    """

    _attribute_map = {
        'report_batch_id': {'key': 'reportBatchId', 'type': 'int'},
        'report_batch_code': {'key': 'reportBatchCode', 'type': 'str'},
        'report_batch_name': {'key': 'reportBatchName', 'type': 'str'},
    }

    def __init__(self, report_batch_id=None, report_batch_code=None, report_batch_name=None):
        super(ReportBatchChild, self).__init__()
        self.report_batch_id = report_batch_id
        self.report_batch_code = report_batch_code
        self.report_batch_name = report_batch_name
