# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsRequest(Model):
    """EnergyStarSettingsRequest.

    :param notification_recipients: List of e-mail notification recipients
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Cannot be Empty</span>
    :type notification_recipients: list[str]
    :param earliest_submission_period: The earliest period to submit <span
     class='property-internal'>Required</span>
    :type earliest_submission_period: int
    """

    _validation = {
        'notification_recipients': {'required': True},
        'earliest_submission_period': {'required': True},
    }

    _attribute_map = {
        'notification_recipients': {'key': 'notificationRecipients', 'type': '[str]'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, notification_recipients, earliest_submission_period):
        super(EnergyStarSettingsRequest, self).__init__()
        self.notification_recipients = notification_recipients
        self.earliest_submission_period = earliest_submission_period
