# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateCreate(Model):
    """RateCreate.

    :param name:  <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 255 characters</span>
    :type name: str
    :param vendor_id:  <span class='property-internal'>Required</span>
    :type vendor_id: int
    :param commodity_id:  <span class='property-internal'>Required</span>
    :type commodity_id: int
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type note: str
    """

    _validation = {
        'name': {'required': True, 'max_length': 255, 'min_length': 0},
        'vendor_id': {'required': True},
        'commodity_id': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, name, vendor_id, commodity_id, note=None):
        super(RateCreate, self).__init__()
        self.name = name
        self.vendor_id = vendor_id
        self.commodity_id = commodity_id
        self.note = note
