# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SubtractResponse(Model):
    """SubtractResponse.

    :param subtract_meters: Meters in this list will have their use or cost
     subtracted during bill calculation
    :type subtract_meters: list[~energycap.sdk.models.MeterChild]
    :param subtract_meter_groups: Distinct meters from these meter groups will
     have their use or cost subtracted together during the bill calculation
    :type subtract_meter_groups: list[~energycap.sdk.models.MeterGroupChild]
    """

    _attribute_map = {
        'subtract_meters': {'key': 'subtractMeters', 'type': '[MeterChild]'},
        'subtract_meter_groups': {'key': 'subtractMeterGroups', 'type': '[MeterGroupChild]'},
    }

    def __init__(self, subtract_meters=None, subtract_meter_groups=None):
        super(SubtractResponse, self).__init__()
        self.subtract_meters = subtract_meters
        self.subtract_meter_groups = subtract_meter_groups
