# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillReversal(Model):
    """BillReversal.

    :param reference_bill_id: Identifier of the other bill in the reversal
     pair
    :type reference_bill_id: int
    :param reference_type: Indicates whether the reference bill is a reversal
     or source of a reversal.
     It is "Source" if the reference bill is the source bill and "Reversal"
     if the reference bill is the reversal bill
    :type reference_type: str
    :param description: Description of the reversal pair
    :type description: str
    """

    _attribute_map = {
        'reference_bill_id': {'key': 'referenceBillId', 'type': 'int'},
        'reference_type': {'key': 'referenceType', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, reference_bill_id=None, reference_type=None, description=None):
        super(BillReversal, self).__init__()
        self.reference_bill_id = reference_bill_id
        self.reference_type = reference_type
        self.description = description
