# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListTypeChild(Model):
    """ListTypeChild.

    :param list_type_id:
    :type list_type_id: int
    :param list_type_info:
    :type list_type_info: str
    :param list_type_description:
    :type list_type_description: str
    """

    _attribute_map = {
        'list_type_id': {'key': 'listTypeId', 'type': 'int'},
        'list_type_info': {'key': 'listTypeInfo', 'type': 'str'},
        'list_type_description': {'key': 'listTypeDescription', 'type': 'str'},
    }

    def __init__(self, list_type_id=None, list_type_info=None, list_type_description=None):
        super(ListTypeChild, self).__init__()
        self.list_type_id = list_type_id
        self.list_type_info = list_type_info
        self.list_type_description = list_type_description
