# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryBodyLine(Model):
    """BillEntryBodyLine.

    :param body_line_id: The body line identifier
    :type body_line_id: int
    :param caption: The body line's caption
    :type caption: str
    :param value:
    :type value: ~energycap.sdk.models.BillEntryBodyLineWithNounChild
    :param cost:
    :type cost: ~energycap.sdk.models.BillEntryBodyLineChild
    :param observation_type:
    :type observation_type:
     ~energycap.sdk.models.BillEntryObservationTypeChild
    """

    _attribute_map = {
        'body_line_id': {'key': 'bodyLineId', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
        'value': {'key': 'value', 'type': 'BillEntryBodyLineWithNounChild'},
        'cost': {'key': 'cost', 'type': 'BillEntryBodyLineChild'},
        'observation_type': {'key': 'observationType', 'type': 'BillEntryObservationTypeChild'},
    }

    def __init__(self, body_line_id=None, caption=None, value=None, cost=None, observation_type=None):
        super(BillEntryBodyLine, self).__init__()
        self.body_line_id = body_line_id
        self.caption = caption
        self.value = value
        self.cost = cost
        self.observation_type = observation_type
