# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateEdit(Model):
    """RateEdit.

    :param name:  <span class='property-internal'>Must be between 0 and 255
     characters</span> <span class='property-internal'>Required
     (defined)</span>
    :type name: str
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span> <span class='property-internal'>Required
     (defined)</span>
    :type note: str
    """

    _validation = {
        'name': {'max_length': 255, 'min_length': 0},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, name=None, note=None):
        super(RateEdit, self).__init__()
        self.name = name
        self.note = note
