# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterRateResponse(Model):
    """MeterRateResponse.

    :param rate_id: The meter tariff identifier
    :type rate_id: int
    :param name: The rate name
    :type name: str
    :param rate_code: The rate code
    :type rate_code: str
    :param start_date: The start date for the rate on the account meter
    :type start_date: datetime
    :param end_date: The end date for the rate on the account meter
    :type end_date: datetime
    :param account:
    :type account: ~energycap.sdk.models.MeterAccountChild
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param note: The rate's note
    :type note: str
    """

    _attribute_map = {
        'rate_id': {'key': 'rateId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'rate_code': {'key': 'rateCode', 'type': 'str'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'account': {'key': 'account', 'type': 'MeterAccountChild'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, rate_id=None, name=None, rate_code=None, start_date=None, end_date=None, account=None, commodity=None, note=None):
        super(MeterRateResponse, self).__init__()
        self.rate_id = rate_id
        self.name = name
        self.rate_code = rate_code
        self.start_date = start_date
        self.end_date = end_date
        self.account = account
        self.commodity = commodity
        self.note = note
