# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GLSubcodeResponse(Model):
    """GLSubcodeResponse.

    :param sub_code_index: Index of this subcode (01-20)
    :type sub_code_index: str
    :param sub_code_name: Name for this SubCode
    :type sub_code_name: str
    :param sub_code_type: SubCodeType - will be "list"(if fixed=1 in DB) or
     "text" (if fixed=0) in DB
    :type sub_code_type: str
    :param sub_code_values: An array of pick list values when this subcode is
     a "list"
    :type sub_code_values: list[str]
    """

    _attribute_map = {
        'sub_code_index': {'key': 'subCodeIndex', 'type': 'str'},
        'sub_code_name': {'key': 'subCodeName', 'type': 'str'},
        'sub_code_type': {'key': 'subCodeType', 'type': 'str'},
        'sub_code_values': {'key': 'subCodeValues', 'type': '[str]'},
    }

    def __init__(self, sub_code_index=None, sub_code_name=None, sub_code_type=None, sub_code_values=None):
        super(GLSubcodeResponse, self).__init__()
        self.sub_code_index = sub_code_index
        self.sub_code_name = sub_code_name
        self.sub_code_type = sub_code_type
        self.sub_code_values = sub_code_values
