# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class LicenseRequest(Model):
    """LicenseRequest.

    :param validation_key: User's license validation key. <span
     class='property-internal'>Required (defined)</span>
    :type validation_key: str
    """

    _attribute_map = {
        'validation_key': {'key': 'validationKey', 'type': 'str'},
    }

    def __init__(self, validation_key=None):
        super(LicenseRequest, self).__init__()
        self.validation_key = validation_key
