# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceSizeCreate(Model):
    """PlaceSizeCreate.

    :param begin_date: The begin date for the place size <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type begin_date: datetime
    :param value: The place size value <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 2147483647</span> <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 2147483647</span>
    :type value: int
    :param unit_code: <p>The place size's unit code</p>
     <p>Options are SQFEET for Square Feet and SQMETER for Square Meters</p>
     <span class='property-internal'>One of SQFEET, SQMETER </span> <span
     class='property-internal'>Must be between 0 and 16 characters</span> <span
     class='property-internal'>One of SQFEET, SQMETER </span> <span
     class='property-internal'>Must be between 0 and 16 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type unit_code: str
    """

    _validation = {
        'begin_date': {'required': True},
        'value': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'unit_code': {'max_length': 16, 'min_length': 0},
    }

    _attribute_map = {
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'int'},
        'unit_code': {'key': 'unitCode', 'type': 'str'},
    }

    def __init__(self, begin_date, value, unit_code=None):
        super(PlaceSizeCreate, self).__init__()
        self.begin_date = begin_date
        self.value = value
        self.unit_code = unit_code
