# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class WebhookEventTypeChild(Model):
    """WebhookEventTypeChild.

    :param webhook_event_type_id: The identifier for the webhook event type
    :type webhook_event_type_id: int
    :param webhook_event_type_name: The name of the webhook event type
    :type webhook_event_type_name: str
    """

    _attribute_map = {
        'webhook_event_type_id': {'key': 'webhookEventTypeId', 'type': 'int'},
        'webhook_event_type_name': {'key': 'webhookEventTypeName', 'type': 'str'},
    }

    def __init__(self, webhook_event_type_id=None, webhook_event_type_name=None):
        super(WebhookEventTypeChild, self).__init__()
        self.webhook_event_type_id = webhook_event_type_id
        self.webhook_event_type_name = webhook_event_type_name
