# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MapPlace(Model):
    """MapPlace.

    :param place_id: The identifier for place
    :type place_id: int
    :param place_code: The place code
    :type place_code: str
    :param place_info: The place information
    :type place_info: str
    :param address:
    :type address: ~energycap.sdk.models.AddressChild
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'address': {'key': 'address', 'type': 'AddressChild'},
    }

    def __init__(self, place_id=None, place_code=None, place_info=None, address=None):
        super(MapPlace, self).__init__()
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.address = address
